A customized airsim API Emulator for special purposes
=====================================================

This is a simple example package for special purpose usages of **Mirosoft AirSim Unmanned Vehicle Simulator**'s python API. It utilizes the use of sBGC commands for gimbal emulation and Visca adaptor for Zoom/FOV controls.

For more information:
----------------------------------------------------
For more information on **AirSim** project checkout [Airsim Project](https://github.com/microsoft/AirSim) gitHub repo.
